@@ -1,13 +1,13 @@
-__version__ = "0.0.11"
+__version__ = "0.0.18"
 
 from .abstract import SMBaseClass
 from .agents import AgentRequestPayload
-from .gupshup import IncomingPayLoad
+from .gupshup import GupshupIncomingPayLoad
 from .keys import KEYS
 
 __all__ = [
     "AgentRequestPayload",
-    "IncomingPayLoad",
+    "GupshupIncomingPayLoad",
     "KEYS",
     "SMBaseClass",
 ]
\ No newline at end of file
