@@ -1,8 +1,8 @@
-from .baseclass import SMBaseClass, ThirdPartyPayload
+from .baseclass import SMBaseClass, ThirdPartyPayloadConsumedByAgent
 from .enforcers import EnforceDocStringBaseClass
 
 __all__ = [
     "SMBaseClass",
-    "ThirdPartyPayload",
+    "ThirdPartyPayloadConsumedByAgent",
     "EnforceDocStringBaseClass",
 ]
\ No newline at end of file
